@@ -45,9 +45,13 @@ is.vectorlist <- function(
 #' @param ... additional parameters of function [is.vectorlist()]
 #' 
 #' @keywords internal
+#' @importFrom spatstat.geom anylist
 #' @export
 as.vectorlist <- function(x, ...) {
   
+  x <- x |> 
+    do.call(what = anylist, args = _)
+  
   if (!is.vectorlist(x, ...)) stop('input does not qualify as a `vectorlist`')
   
   attr(x, which = 'mode') <- mode(x[[1L]])
